==> startapp_sdk_flutter-0.0.6.tar.gz: lib/src/startapp_banner.dart <==

import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:startapp_sdk_flutter/src/startapp_banner_size.dart';
import 'package:startapp_sdk_flutter/src/startapp_controller.dart';
import 'package:startapp_sdk_flutter/src/startapp_event.dart';

class StartappBanner extends StatefulWidget {
   final void Function(StartappEvent) listener;
  final void Function(StartappBannerController) onBannerCreated;
  final StartappBannerSize adSize;
  const StartappBanner({
    Key key,
    this.adSize,
    this.onBannerCreated,
    this.listener
  }) : super(key: key);

  @override
  State<StartappBanner> createState() => _BannerState();
}

class _BannerState extends State<StartappBanner> {
  UniqueKey _key = UniqueKey();
  @override
  Widget build(BuildContext context) {
    if (defaultTargetPlatform == TargetPlatform.android) {
      return Container(
          width: widget.adSize.width >= 0 ? widget.adSize.width.toDouble() : double.infinity,
          height: widget.adSize.height >= 0 ? widget.adSize.height.toDouble() : double.infinity,
          child: AndroidView(
            key: _key,
            viewType: 'startapp/banner',
            creationParams: <String, dynamic>{
              "width": widget.adSize.width,
              "height": widget.adSize.height,
            },
            creationParamsCodec: const StandardMessageCodec(),
            onPlatformViewCreated: _onPlatformViewCreated,
          ));
    } else if (defaultTargetPlatform == TargetPlatform.iOS) {
      return Container(
          width: widget.adSize.width.toDouble(),
          height: widget.adSize.height.toDouble(),
          child: UiKitView(
            key: _key,
            creationParams: <String, dynamic>{
              "width": widget.adSize.width,
              "height": widget.adSize.height,
            },
            viewType: 'startapp/banner',
            creationParamsCodec: const StandardMessageCodec(),
            onPlatformViewCreated: _onPlatformViewCreated,
          ));
    }
    return Text('$defaultTargetPlatform is no need showing ads');
  }

  @override
  void dispose() {
    super.dispose();
  }

  void _onPlatformViewCreated(int id) {
    StartappBannerController controller = new StartappBannerController(id, widget.listener);
    if (widget.onBannerCreated != null) {
      widget.onBannerCreated(controller);
    }
  }
}

==> startapp_sdk_flutter-0.0.8.tar.gz: lib/src/startapp_banner.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:startapp_sdk_flutter/src/startapp_banner_size.dart';
import 'package:startapp_sdk_flutter/src/startapp_controller.dart';
import 'package:startapp_sdk_flutter/src/startapp_event.dart';

class StartappBanner extends StatefulWidget {
  final void Function(StartappEvent) listener;
  final void Function(StartappBannerController) onBannerCreated;
  final StartappBannerSize adSize;
  const StartappBanner(
      {Key key, this.adSize, this.onBannerCreated, this.listener})
      : super(key: key);

  @override
  State<StartappBanner> createState() => _BannerState();
}

class _BannerState extends State<StartappBanner> {
  UniqueKey _key = UniqueKey();
  @override
  Widget build(BuildContext context) {
    if (defaultTargetPlatform == TargetPlatform.android) {
      return Container(
          padding: EdgeInsets.zero,
          width: widget.adSize.width >= 0
              ? widget.adSize.width.toDouble()
              : double.infinity,
          height: widget.adSize.height >= 0
              ? widget.adSize.height.toDouble()
              : double.infinity,
          child: AndroidView(
            key: _key,
            viewType: 'startapp/banner',
            creationParams: <String, dynamic>{
              "width": widget.adSize.width,
              "height": widget.adSize.height,
            },
            creationParamsCodec: const StandardMessageCodec(),
            onPlatformViewCreated: _onPlatformViewCreated,
          ));
    } else if (defaultTargetPlatform == TargetPlatform.iOS) {
      return Container(
          padding: EdgeInsets.zero,
          width: widget.adSize.width.toDouble(),
          height: widget.adSize.height.toDouble(),
          child: UiKitView(
            key: _key,
            creationParams: <String, dynamic>{
              "width": widget.adSize.width,
              "height": widget.adSize.height,
            },
            viewType: 'startapp/banner',
            creationParamsCodec: const StandardMessageCodec(),
            onPlatformViewCreated: _onPlatformViewCreated,
          ));
    }
    return Text('$defaultTargetPlatform is no need showing ads');
  }

  @override
  void dispose() {
    super.dispose();
  }

  void _onPlatformViewCreated(int id) {
    StartappBannerController controller =
        new StartappBannerController(id, widget.listener);
    if (widget.onBannerCreated != null) {
      widget.onBannerCreated(controller);
    }
  }
}
